@@ -990,13 +990,22 @@ class account():
             print nowstring
             return nowstring
 
-            return msgDate.ctime()
-        except ValueError:
-            msgDate = datetime.datetime.strptime(timestr, "%a %b %d %Y %H:%M:%S +0000")
-            #msgDate = date.fromtimestamp(secsSinceEpoc)
 
+        except ValueError:
+            msgDate = datetime.datetime.strptime(timestr, "%a, %d %b %Y %H:%M:%S +0000")
+            #msgDate = date.fromtimestamp(secsSinceEpoc)
+            # we want something like '2007-10-18 14:00+0100'
+            t = time.time()
+            if time.localtime(t).tm_isdst and time.daylight:
+                tz = time.altzone
+            else:
+                tz = time.timezone
+
+            td = datetime.timedelta(seconds=tz)
+            timestamp = msgDate - td
+            nowstring = timestamp.strftime('%a, %b %d %Y %H:%M:%S')
             today = datetime.date.today()
 
             #print datetime.datetime.tzname()
             #msgDate = msgDate.astimezone(datetime.tzinfo("GMT +1"))
-            return msgDate.ctime()
+            return nowstring
